@@ -662,7 +662,7 @@ void ConfigurationHandler::onTcpServerConfigurationChanged(const QString &id)
 
 void ConfigurationHandler::onTcpServerConfigurationRemoved(const QString &id)
 {
-    qCDebug(dcJsonRpc) << "Notification: TCP server configuration removed";
+    qCDebug(dcJsonRpc()) << "Notification: TCP server configuration removed";
     QVariantMap params;
     params.insert("id", id);
     emit TcpServerConfigurationRemoved(params);
@@ -753,7 +753,7 @@ QVariantMap ConfigurationHandler::packBasicConfiguration()
     QVariantMap basicConfiguration;
     basicConfiguration.insert("serverName", NymeaCore::instance()->configuration()->serverName());
     basicConfiguration.insert("serverUuid", NymeaCore::instance()->configuration()->serverUuid().toString());
-    basicConfiguration.insert("serverTime", NymeaCore::instance()->timeManager()->currentDateTime().toTime_t());
+    basicConfiguration.insert("serverTime", NymeaCore::instance()->timeManager()->currentDateTime().toSecsSinceEpoch());
     basicConfiguration.insert("timeZone", QTimeZone::systemTimeZoneId());
     basicConfiguration.insert("language", NymeaCore::instance()->configuration()->locale().name());
     basicConfiguration.insert("location", QVariantMap{
