@@ -89,10 +89,11 @@
 #include "debugserverhandler.h"
 #include "version.h"
 
-#include <QJsonDocument>
+#include <QRegularExpression>
 #include <QNetworkInterface>
 #include <QXmlStreamWriter>
 #include <QCoreApplication>
+#include <QJsonDocument>
 #include <QTcpServer>
 #include <QTcpSocket>
 #include <QSslSocket>
@@ -268,15 +269,20 @@ void WebServer::incomingConnection(qintptr socketDescriptor)
     if (m_configuration.sslEnabled) {
         // configure client connection
         socket->setSslConfiguration(m_sslConfiguration);
-        connect(socket, SIGNAL(encrypted()), this, SLOT(onEncrypted()));
+        connect(socket, &QSslSocket::encrypted, this, &WebServer::onEncrypted);
         socket->startServerEncryption();
         // wait for encrypted connection before continue with this client
         return;
     }
 
-    connect(socket, SIGNAL(readyRead()), this, SLOT(readClient()));
-    connect(socket, SIGNAL(disconnected()), this, SLOT(onDisconnected()));
+    connect(socket, &QSslSocket::readyRead, this, &WebServer::readClient);
+    connect(socket, &QSslSocket::disconnected, this, &WebServer::onDisconnected);
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    connect(socket, &QSslSocket::errorOccurred, this, &WebServer::onError);
+#else
     connect(socket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(onError(QAbstractSocket::SocketError)));
+#endif
 
     emit clientConnected(clientId);
 }
@@ -419,7 +425,7 @@ void WebServer::readClient()
         // Check if the webinterface dir does exist, otherwise a filerequest is not relevant
         // FIXME: return a default webpage containing server information
         if (!QDir(m_configuration.publicFolder).exists()) {
-            qDebug(dcWebServer()) << "Webinterface folder" << m_configuration.publicFolder << "does not exist.";
+            qCDebug(dcWebServer()) << "Webinterface folder" << m_configuration.publicFolder << "does not exist.";
             HttpReply *reply = HttpReply::createErrorReply(HttpReply::NotFound);
             reply->setClientId(clientId);
             sendHttpReply(reply);
@@ -508,10 +514,14 @@ void WebServer::onEncrypted()
 {
     QSslSocket* socket = static_cast<QSslSocket *>(sender());
     qCDebug(dcWebServer()).noquote() << QString("Encrypted connection %1:%2 successfully established.").arg(socket->peerAddress().toString()).arg(socket->peerPort());
-    connect(socket, SIGNAL(readyRead()), this, SLOT(readClient()));
-    connect(socket, SIGNAL(disconnected()), this, SLOT(onDisconnected()));
-    connect(socket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(onError(QAbstractSocket::SocketError)));
+    connect(socket, &QSslSocket::readyRead, this, &WebServer::readClient);
+    connect(socket, &QSslSocket::disconnected, this, &WebServer::onDisconnected);
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    connect(socket, &QSslSocket::errorOccurred, this, &WebServer::onError);
+#else
+    connect(socket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(onError(QAbstractSocket::SocketError)));
+#endif
     emit clientConnected(m_clientList.key(socket));
 }
 
@@ -593,7 +603,7 @@ WebServerConfiguration WebServer::configuration() const
 
 QByteArray WebServer::createServerXmlDocument(QHostAddress address)
 {
-    QByteArray uuid = NymeaCore::instance()->configuration()->serverUuid().toString().remove(QRegExp("[{}]")).toUtf8();
+    QByteArray uuid = NymeaCore::instance()->configuration()->serverUuid().toString().remove(QRegularExpression("[{}]")).toUtf8();
 
     QByteArray data;
     QXmlStreamWriter writer(&data);
