@@ -134,6 +134,7 @@
 #include "types/event.h"
 #include "loggingcategories.h"
 #include "statevaluefilters/statevaluefilteradaptive.h"
+#include "thingutils.h"
 
 #include <QJsonDocument>
 #include <QDebug>
@@ -385,11 +386,11 @@ void Thing::setStateValue(const StateTypeId &stateTypeId, const QVariant &value)
                 return;
             }
             State state = m_states.at(i);
-            if (state.minValue().isValid() && value < state.minValue()) {
+            if (state.minValue().isValid() && ThingUtils::variantLessThan(value, state.minValue())) {
                 qCWarning(dcThing()).nospace() << this << ": Invalid value " << value << " for state " << stateType.name() << ". Out of range: " << state.minValue() << " - " << state.maxValue() << " (Correcting to closest value within range)";
                 newValue = state.minValue();
             }
-            if (state.maxValue().isValid() && value > state.maxValue()) {
+            if (state.maxValue().isValid() && ThingUtils::variantGreaterThan(value, state.maxValue())) {
                 qCWarning(dcThing()).nospace() << this << ": Invalid value " << value << " for state " << stateType.name() << ". Out of range: " << state.minValue() << " - " << state.maxValue() << " (Correcting to closest value within range)";
                 newValue = state.maxValue();
             }
@@ -418,7 +419,7 @@ void Thing::setStateValue(const StateTypeId &stateTypeId, const QVariant &value)
         }
     }
     Q_ASSERT_X(false, m_name.toUtf8(), QString("Failed setting state %1 to %2").arg(stateType.name()).arg(value.toString()).toUtf8());
-    qCWarning(dcThing).nospace() << this << ": Failed setting state " << stateType.name() << " to " << value;
+    qCWarning(dcThing()).nospace() << this << ": Failed setting state " << stateType.name() << " to " << value;
 }
 
 /*! Sets the value for the \l{State} matching the given \a stateName in this thing to value. */
@@ -452,11 +453,11 @@ void Thing::setStateMinValue(const StateTypeId &stateTypeId, const QVariant &min
             m_states[i].setMinValue(newMin);
 
             // Sanity check for max >= min
-            if (m_states.at(i).maxValue() < newMin) {
+            if (ThingUtils::variantLessThan(m_states.at(i).maxValue(), newMin)) {
                 qCWarning(dcThing()).nospace() << this << ": Adjusting state maximum value for " << stateType.name() << " from " << m_states.at(i).maxValue() << " to new minimum value of " << newMin;
                 m_states[i].setMaxValue(newMin);
             }
-            if (m_states.at(i).value() < newMin) {
+            if (ThingUtils::variantLessThan(m_states.at(i).value(), newMin)) {
                 qCInfo(dcThing()).nospace() << this << ": Adjusting state value for " << stateType.name() << " from " << m_states.at(i).value() << " to new minimum value of " << newMin;
                 m_states[i].setValue(newMin);
             }
@@ -466,7 +467,7 @@ void Thing::setStateMinValue(const StateTypeId &stateTypeId, const QVariant &min
         }
     }
     Q_ASSERT_X(false, m_name.toUtf8(), QString("Failed setting minimum state value %1 to %2").arg(stateType.name()).arg(minValue.toString()).toUtf8());
-    qCWarning(dcThing).nospace() << this << ": Failed setting minimum state value " << stateType.name() << " to " << minValue;
+    qCWarning(dcThing()).nospace() << this << ": Failed setting minimum state value " << stateType.name() << " to " << minValue;
 }
 
 /*! Sets the minimum value for the \l{State} matching the given \a stateName in this thing to value. */
@@ -496,12 +497,12 @@ void Thing::setStateMaxValue(const StateTypeId &stateTypeId, const QVariant &max
 
             if (newMax.isValid()) {
                 // Sanity check for min <= max
-                if (m_states.at(i).minValue() > newMax) {
+                if (ThingUtils::variantGreaterThan(m_states.at(i).minValue(), newMax)) {
                     qCWarning(dcThing()).nospace() << this << ": Adjusting minimum state value for " << stateType.name() << " from " << m_states.at(i).minValue() << " to new maximum value of " << newMax;
                     m_states[i].setMinValue(newMax);
                 }
 
-                if (m_states.at(i).value() > newMax) {
+                if (ThingUtils::variantGreaterThan(m_states.at(i).value(), newMax)) {
                     qCInfo(dcThing()).nospace() << this << ": Adjusting state value for " << stateType.name() << " from " << m_states.at(i).value() << " to new maximum value of " << newMax;
                     m_states[i].setValue(maxValue);
                 }
@@ -512,7 +513,7 @@ void Thing::setStateMaxValue(const StateTypeId &stateTypeId, const QVariant &max
         }
     }
     Q_ASSERT_X(false, m_name.toUtf8(), QString("Failed setting maximum state value %1 to %2").arg(stateType.name()).arg(maxValue.toString()).toUtf8());
-    qCWarning(dcThing).nospace() << this << ": Failed setting maximum state value " << stateType.name() << " to " << maxValue;
+    qCWarning(dcThing()).nospace() << this << ": Failed setting maximum state value " << stateType.name() << " to " << maxValue;
 }
 
 /*! Sets the maximum value for the \l{State} matching the given \a stateName in this thing to value. */
@@ -543,16 +544,16 @@ void Thing::setStateMinMaxValues(const StateTypeId &stateTypeId, const QVariant
 
             if (newMax.isValid() || newMax.isValid()) {
                 // Sanity check for min <= max
-                if (newMin > newMax) {
+                if (ThingUtils::variantGreaterThan(newMin, newMax)) {
                     qCWarning(dcThing()).nospace() << this << ": Adjusting maximum state value for " << stateType.name() << " from " << m_states.at(i).maxValue() << " to new minimum value of " << newMax;
                     m_states[i].setMaxValue(newMin);
                 }
 
-                if (m_states.at(i).value() < m_states.at(i).minValue()) {
+                if (ThingUtils::variantLessThan(m_states.at(i).value(), m_states.at(i).minValue())) {
                     qCInfo(dcThing()).nospace() << this << ": Adjusting state value for " << stateType.name() << " from " << m_states.at(i).value() << " to new minimum value of " << m_states.at(i).minValue();
                     m_states[i].setValue(m_states.at(i).minValue());
                 }
-                if (m_states.at(i).value() > m_states.at(i).maxValue()) {
+                if (ThingUtils::variantGreaterThan(m_states.at(i).value(), m_states.at(i).maxValue())) {
                     qCInfo(dcThing()).nospace() << this << ": Adjusting state value for " << stateType.name() << " from " << m_states.at(i).value() << " to new maximum value of " << m_states.at(i).maxValue();
                     m_states[i].setValue(m_states.at(i).maxValue());
                 }
@@ -563,7 +564,7 @@ void Thing::setStateMinMaxValues(const StateTypeId &stateTypeId, const QVariant
         }
     }
     Q_ASSERT_X(false, m_name.toUtf8(), QString("Failed setting maximum state value %1 to %2").arg(stateType.name()).arg(maxValue.toString()).toUtf8());
-    qCWarning(dcThing).nospace() << this << ": Failed setting maximum state value " << stateType.name() << " to " << maxValue;
+    qCWarning(dcThing()).nospace() << this << ": Failed setting maximum state value " << stateType.name() << " to " << maxValue;
 
 }
 
@@ -590,10 +591,10 @@ void Thing::setStatePossibleValues(const StateTypeId &stateTypeId, const QVarian
 
             if (!values.contains(m_states.value(i).value())) {
                 if (values.contains(stateType.defaultValue())) {
-                    qCInfo(dcThing).nospace() << this << ": Adjusting state value for " << stateType.name() << " from " << m_states.at(i).value() << " to default value of " << stateType.defaultValue();
+                    qCInfo(dcThing()).nospace() << this << ": Adjusting state value for " << stateType.name() << " from " << m_states.at(i).value() << " to default value of " << stateType.defaultValue();
                     m_states[i].setValue(stateType.defaultValue());
                 } else if (!values.isEmpty()) {
-                    qCInfo(dcThing).nospace() << this << ": Adjusting state value for " << stateType.name() << " from " << m_states.at(i).value() << " to new value of " << values.first();
+                    qCInfo(dcThing()).nospace() << this << ": Adjusting state value for " << stateType.name() << " from " << m_states.at(i).value() << " to new value of " << values.first();
                     m_states[i].setValue(values.first());
                 }
             }
@@ -601,7 +602,7 @@ void Thing::setStatePossibleValues(const StateTypeId &stateTypeId, const QVarian
             return;
         }
     }
-    qCWarning(dcThing).nospace() << this << ": Failed setting maximum state value " << stateType.name() << " to " << values;
+    qCWarning(dcThing()).nospace() << this << ": Failed setting maximum state value " << stateType.name() << " to " << values;
     Q_ASSERT_X(false, m_name.toUtf8(), QString("Failed setting possible state values for %1 to %2").arg(stateType.name()).arg(QString(QJsonDocument::fromVariant(values).toJson())).toUtf8());
 
 }
